@@ -105,7 +105,7 @@ class Task(APIResource):
                timeout: int = 7200, cost_matrix_weights: List[List[str]] = None, train_size: float = None,
                test_size: float = None, validation_size: float = None, fold_size: int = None, n_folds: int = None,
                horizon: int = None, validation_strategy: ValidationStrategy = None, cv_strategy: CVStrategy = None,
-               forecast_horizon: int = 10, model_life_time: int = 0, refit_on_all: bool = None, wait: bool = False,
+               forecast_horizon: int = None, model_life_time: int = None, refit_on_all: bool = None, wait: bool = False,
                skip_if_exists: bool = False, api_key: str = None) -> FireflyResponse:
         """
         Create and run a training task.
@@ -154,7 +154,6 @@ class Task(APIResource):
         """
         if horizon is not None:
             logger.warning("Parameter `horizon` is DEPRECATED. Please use `forecast_horizon` and `model_life_time`.")
-        horizon = (model_life_time or 0) + (forecast_horizon or 10)
 
         existing_ds = cls.list(filter_={'name': [name]}, api_key=api_key)
         if existing_ds and existing_ds['total'] > 0:
@@ -192,7 +191,6 @@ class Task(APIResource):
             'validation_size': validation_size,
             'cv_strategy': cv_strategy.value if cv_strategy is not None else None,
             'n_folds': n_folds,
-            'horizon': horizon,
             'forecast_horizon': forecast_horizon,
             'model_life_time': model_life_time,
             'fold_size': fold_size,
@@ -200,7 +198,7 @@ class Task(APIResource):
             'notes': notes,
             'refit_on_all': refit_on_all
         }
-        task_config.update({k: v for k, v in user_config.items() if v})
+        task_config.update({k: v for k, v in user_config.items() if v is not None})
 
         requestor = APIRequestor()
         response = requestor.post(url=cls._CLASS_PREFIX, body=task_config, api_key=api_key)
